==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/lwdates.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP procedure IF EXISTS lwdates//
create procedure lwdates(lwid integer, dt date)

  deterministic
  sql security invoker
 begin
   declare sid, sec, tst, det, aid integer;
   declare p enum('H','D','W','M','s');
   declare fd, ld date;

  if not exists (select * from lwertedates where lwerteindizesID = lwid and fdate <= dt and dt <= ldate) then
    set fd = NULL;
    set ld = '0000-00-00';
    select fdate, ldate from lwertedates
        where lwerteindizesID = lwid and fdate <= dt and dt - interval 1 day <= ldate
        order by ldate desc, fdate desc
        limit 1
      into fd, ld;
    if ld < dt then
      select serverID, sectionID, teststepID, teststepdetailsID, accessID, left(period, 1)
        from lwerteindizes where ID = lwid
        into sid, sec, tst, det, aid, p;
      if fd is NULL then
        insert ignore into lwertedates
          (lwerteindizesID, serverID, sectionID, teststepID, teststepdetailsID, accessID, period, fdate, ldate)
          values (lwid, sid, sec, tst, det, aid, p, dt, dt);
      else
        update lwertedates set ldate = dt
          where lwerteindizesID = lwid and fdate = fd and ldate <= dt;
      end if;
      set fd = NULL;
      set ld = '0000-00-00';
      select fdate, ldate from lteststepdates
          where serverID = sid and sectionID = sec and teststepID = tst and period = p and accessID = aid
            and fdate <= dt and dt - interval 1 day <= ldate
          order by ldate desc, fdate desc
          limit 1
        into fd, ld;
      if ld < dt then
        if fd is NULL then
          insert ignore into lteststepdates
            (serverID, sectionID, teststepID, accessID, period, fdate, ldate)
            values (sid, sec, tst, aid, p, dt, dt);
        else
          update lteststepdates set ldate = dt
            where serverID = sid and sectionID = sec and teststepID = tst and period = p and accessID = aid
              and fdate = fd and ldate <= dt;
        end if;
        set fd = NULL;
        set ld = '0000-00-00';
        select fdate, ldate from lsectiondates
            where serverID = sid and sectionID = sec and period = p and accessID = aid
              and fdate <= dt and dt - interval 1 day <= ldate
            order by ldate desc, fdate desc
            limit 1
          into fd, ld;
        if ld < dt then
          if fd is NULL then
            insert ignore into lsectiondates (serverID, sectionID, accessID, period, fdate, ldate)
              values (sid, sec, aid, p, dt, dt);
          else
            update lsectiondates set ldate = dt
              where serverID = sid and sectionID = sec and period = p and accessID = aid
                and fdate = fd and ldate <= dt;
          end if;
          set fd = NULL;
          set ld = '0000-00-00';
          select fdate, ldate from lserverdates
              where serverID = sid and period = p and accessID = aid
                and fdate <= dt and dt - interval 1 day <= ldate
              order by ldate desc, fdate desc
              limit 1
            into fd, ld;
          if ld < dt then
            if fd is NULL then
              insert ignore into lserverdates (serverID, period, accessID, fdate, ldate)
              values (sid, p, aid, dt, dt);
            else
              update lserverdates set ldate = dt
                where serverID = sid and period = p and accessID = aid
                  and fdate = fd and ldate <= dt;
            end if;
          end if;
        end if;
      end if;
    end if;
  end if;
end//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/lwdates.sql <==
-- lwdates.sql
--
-- procedure lwdates(lwid, dt)
-- lwid: lwerteindizesID
-- dt: date
--
-- update or insert lwertedates, lteststepdates, lsectiondates and lserverdates

set @@character_set_client = 'utf8';

delimiter //

DROP procedure IF EXISTS lwdates//
create procedure lwdates(lwid integer, dt date)

  deterministic
  sql security invoker
 begin
   declare sid, sec, tst, det, aid integer;
   declare p enum('H','D','W','M','s');
   declare fd, ld date;

  if not exists (select * from lwertedates where lwerteindizesID = lwid and fdate <= dt and dt <= ldate) then
    set fd = NULL;
    set ld = '0000-00-00';
    select fdate, ldate into fd, ld from lwertedates
        where lwerteindizesID = lwid and fdate <= dt and dt - interval 1 day <= ldate
        order by ldate desc, fdate desc
        limit 1;
    if ld < dt then
      select serverID, sectionID, teststepID, teststepdetailsID, accessID, left(period, 1)
        into sid, sec, tst, det, aid, p
        from lwerteindizes where ID = lwid;
      if fd is NULL then
        insert ignore into lwertedates
          (lwerteindizesID, serverID, sectionID, teststepID, teststepdetailsID, accessID, period, fdate, ldate)
          values (lwid, sid, sec, tst, det, aid, p, dt, dt);
      else
        update lwertedates set ldate = dt
          where lwerteindizesID = lwid and fdate = fd and ldate <= dt;
      end if;
      set fd = NULL;
      set ld = '0000-00-00';
      select fdate, ldate into fd, ld from lteststepdates
          where serverID = sid and sectionID = sec and teststepID = tst and period = p and accessID = aid
            and fdate <= dt and dt - interval 1 day <= ldate
          order by ldate desc, fdate desc
          limit 1;
      if ld < dt then
        if fd is NULL then
          insert ignore into lteststepdates
            (serverID, sectionID, teststepID, accessID, period, fdate, ldate)
            values (sid, sec, tst, aid, p, dt, dt);
        else
          update lteststepdates set ldate = dt
            where serverID = sid and sectionID = sec and teststepID = tst and period = p and accessID = aid
              and fdate = fd and ldate <= dt;
        end if;
        set fd = NULL;
        set ld = '0000-00-00';
        select fdate, ldate into fd, ld from lsectiondates
            where serverID = sid and sectionID = sec and period = p and accessID = aid
              and fdate <= dt and dt - interval 1 day <= ldate
            order by ldate desc, fdate desc
            limit 1;
        if ld < dt then
          if fd is NULL then
            insert ignore into lsectiondates (serverID, sectionID, accessID, period, fdate, ldate)
              values (sid, sec, aid, p, dt, dt);
          else
            update lsectiondates set ldate = dt
              where serverID = sid and sectionID = sec and period = p and accessID = aid
                and fdate = fd and ldate <= dt;
          end if;
          set fd = NULL;
          set ld = '0000-00-00';
          select fdate, ldate into fd, ld from lserverdates
              where serverID = sid and period = p and accessID = aid
                and fdate <= dt and dt - interval 1 day <= ldate
              order by ldate desc, fdate desc
              limit 1;
          if ld < dt then
            if fd is NULL then
              insert ignore into lserverdates (serverID, period, accessID, fdate, ldate)
              values (sid, p, aid, dt, dt);
            else
              update lserverdates set ldate = dt
                where serverID = sid and period = p and accessID = aid
                  and fdate = fd and ldate <= dt;
            end if;
          end if;
        end if;
      end if;
    end if;
  end if;
end//
